@@ -90,7 +90,8 @@ subgroupStage <- function(dat,
 
   sub_spec_comb <- do.call(rbind, sub_spec)
   ind           <- merge(sub$sub_mem, sub_spec_comb, "sub_membership", all.x = TRUE)
-  ind           <- ind[order(ind$index),]
+  if (is.null(confirm_subgroup))
+    ind           <- ind[order(ind$index),] # only get this in exploratory
   ind$sub_paths[is.na(ind$sub_paths)] <- ""
   temp_count    <- grp$n_group_paths
 
@@ -160,7 +161,8 @@ subgroupStage <- function(dat,
   sub_spec_comb <- do.call(rbind, sub_spec)
   ind           <- merge(sub$sub_mem, sub_spec_comb, "sub_membership", all.x = TRUE)
   ind$sub_paths[is.na(ind$sub_paths)] <- ""
-  ind           <- ind[order(ind$index),]
+  if (is.null(confirm_subgroup))
+    ind           <- ind[order(ind$index),]
 
 
   return(list(
